@@ -1,7 +1,7 @@
 package App::orgsel;
 
-our $DATE = '2016-08-27'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2016-08-30'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -17,7 +17,7 @@ $SPEC{orgsel} = {
     summary => 'Select Org document elements using CSel (CSS-selector-like) syntax',
     args => {
         %App::CSelUtils::foosel_common_args,
-        %App::CSelUtils::foosel_action_args,
+        %App::CSelUtils::foosel_tree_action_args,
     },
 };
 sub orgsel {
@@ -68,7 +68,7 @@ App::orgsel - Select Org document elements using CSel (CSS-selector-like) syntax
 
 =head1 VERSION
 
-This document describes version 0.003 of App::orgsel (from Perl distribution App-orgsel), released on 2016-08-27.
+This document describes version 0.004 of App::orgsel (from Perl distribution App-orgsel), released on 2016-08-30.
 
 =head1 SYNOPSIS
 
@@ -85,6 +85,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<actions> => I<array[str]> (default: ["print_as_string"])
+
+Specify action(s) to perform on matching nodes.
+
 =item * B<expr>* => I<str>
 
 =item * B<file> => I<str> (default: "-")
